@@ -26,7 +26,6 @@ else:
 USE_PROGRESSBAR = False
 USE_GRID_LAYOUT = False
 DEFAULT_WINSIZE = '500x400'
-ENABLE_FULLSCREEN = True
 TREEVIEW_ROW_HEIGHT = 21
 VERBOSE = False
 
@@ -318,45 +317,56 @@ class FileSearchFrame(ttk.Frame):
         )
         btn.pack(side=LEFT, fill=X, expand=YES)         
 
-    def preview_image(self):
+    def get_current_selection(self):
 
         if self.resultview.selection() is None or len(self.resultview.selection()) <= 0:
-            Messagebox.show_error('需要先选中一张图片','Error')
-            return
+            if self.master.attributes('-fullscreen'):
+                toast = ToastNotification(
+                    title='Error',
+                    message='需要先选中一张图片', 
+                    duration=1000,
+                )
+                toast.show_toast()
+            else:
+                Messagebox.show_error('需要先选中一张图片','Error')
+            return None
 
         curItem = self.resultview.selection()[0] # self.resultview.focus()
-        imgpath = self.resultview.item(curItem, 'values')[4]
-        
-        toast = ToastNotificationX(
-            image=imgpath,            
-            duration=3000,
-        )
-        toast.show_toast()
+        return curItem
+
+    def preview_image(self):
+
+        curItem = self.get_current_selection()
+        if curItem:
+            imgpath = self.resultview.item(curItem, 'values')[4]            
+            toast = ToastNotificationX(
+                image=imgpath,            
+                duration=3000,
+            )
+            toast.show_toast()
 
     def delete_image(self):
 
-        if self.resultview.selection() is None or len(self.resultview.selection()) <= 0:
-            Messagebox.show_error('需要先选中一张图片','Error')
-            return
-
-        curItem = self.resultview.selection()[0]
-        if curItem is not None:
+        curItem = self.get_current_selection()
+        if curItem:            
             imgpath = self.resultview.item(curItem, 'values')[4]
-            if Messagebox.okcancel(imgpath,'确定删除该图片?') == 'OK':
+            
+            confirmed = True
+            if not self.master.attributes('-fullscreen'):
+                confirmed = Messagebox.okcancel(imgpath,'确定删除该图片?') == 'OK'
+
+            if confirmed:
                 self.resultview.delete(curItem)
                 # send2trash(imgpath) # raize OSError
                 shutil.move (imgpath, imgpath+'.tmp') # don't really delete
 
     def upload_image(self):
 
-        if self.resultview.selection() is None or len(self.resultview.selection()) <= 0:
-            Messagebox.show_error('需要先选中一张图片','Error')
-            return
-
-        curItem = self.resultview.selection()[0] # self.resultview.focus()
-        imgpath = self.resultview.item(curItem, 'values')[4]
-        self.send_data_to_server(imgpath, {'operator':'zys','timestamp': datetime.now()})
-    
+        curItem = self.get_current_selection()
+        if curItem:          
+            imgpath = self.resultview.item(curItem, 'values')[4]
+            self.send_data_to_server(imgpath, {'operator':'zys','timestamp': datetime.now()})
+        
     def send_data_to_server(self, image_path, metadata):
             
         image_filename = os.path.basename(image_path)    
@@ -364,7 +374,17 @@ class FileSearchFrame(ttk.Frame):
             'image': (image_filename, open(image_path, 'rb')),
             'metadata': ('', str(metadata)),
         }
-        Messagebox.show_info(str(multipart_form_data), 'Upload to Server')
+
+        if self.master.attributes('-fullscreen'):
+            toast = ToastNotification(
+                title='Upload to Server',
+                message=str(multipart_form_data), 
+                duration=1000,
+            )
+            toast.show_toast()
+        else:
+            Messagebox.show_info(str(multipart_form_data), 'Upload to Server')
+        
         return    
         response = requests.post('http://www.example.com/api/v1/sensor_data/',
                                 files=multipart_form_data)    
@@ -518,5 +538,5 @@ if __name__ == '__main__':
     app = ttk.Window("文件一览") # , "cyborg")
     FileSearchFrame(app, None)
     app.geometry(DEFAULT_WINSIZE)
-    app.attributes('-fullscreen', ENABLE_FULLSCREEN)
+    app.attributes('-fullscreen', False)
     app.mainloop()
\ No newline at end of file
