@@ -28,7 +28,7 @@ INTERVAL = 100 # ms
 SAVE_DIR = 'ocam_captures/'
 PADDING = 9
 DEFAULT_WINSIZE = '500x400'
-ENABLE_FULLSCREEN = True
+ENABLE_FULLSCREEN = True # NOTE: messagebox can be hided by fullscreen windows. 
 PATH = Path(__file__).parent
 
 def get_timestamp():   
@@ -97,7 +97,26 @@ class MainApp(ttk.Frame):
         # self.demo_media = ttk.PhotoImage(file=img_path)
         self.media = ttk.Label(self) # , image=self.demo_media)
         self.media.pack(fill=BOTH, expand=YES)
-    
+
+        self.print_camera_properties()
+
+    def print_camera_properties(self):
+
+        properties = []
+        for name in dir(cv2):
+            if name.startswith('CAP_PROP'):
+                value = getattr(cv2, name)
+                properties.append((value, name))
+                
+        # it will sort by values
+        # originally it is sorted by names
+        properties = sorted(properties)
+
+        if (len(properties) > 0):
+            print('\n------- Camera Properties ------\n')
+            for value, name in properties:
+                print(f' {value:5} | cv2.{name}')
+
     def create_buttonbox(self):
         """Create buttonbox with media controls"""
 
@@ -269,7 +288,7 @@ class MainApp(ttk.Frame):
         newWindow.title("Data Entry")
     
         # sets the geometry of toplevel
-        newWindow.geometry("400x300")
+        newWindow.geometry(DEFAULT_WINSIZE)
     
         # A Label widget to show in toplevel
         ttk.Label(newWindow,
@@ -292,8 +311,9 @@ if __name__ == '__main__':
     app = ttk.Window("oCam", "yeti")
     app.geometry(DEFAULT_WINSIZE)
     app.attributes('-fullscreen', ENABLE_FULLSCREEN)
+    app.state('zoomed')
     mp = MainApp(app)
-
+    
     # use either q or esc to close window
     app.bind('<q>', key_handler)
     app.bind('<Escape>', lambda event: sys.exit())
