@@ -7,7 +7,14 @@
 # ADC.read(channal)	# 通道选择范围为0-3
 # ADC.write(Value)	# 值的范围为：0-255
 #####################################################
-import smbus
+import sys
+import os.path
+if sys.platform == 'win32':
+    sys.path.append(os.path.dirname(__file__))
+    from simulator import SMBus
+else:
+    from smbus import SMBus
+
 import time
 
 I2C_ADC = 0x48
@@ -15,7 +22,7 @@ RUNNING = True
 
 # While SMBus is derived from I²C, there are several major differences between the specifications of the two busses in the areas of electricals, timing, protocols and operating modes. 
 # 对应比较旧的版本如RPI V1 版本，则 "bus = smbus.SMBus(0)"
-bus = smbus.SMBus(1)
+bus = SMBus(1)
 
 def setup(Addr = I2C_ADC):
 	global address
