@@ -98,7 +98,7 @@ def print_used_pins():
     os.system('pinout')
     print (USED_PINS)
   
-def t_up(speed = SPEED,t_time = TIME):
+def t_up(speed = SPEED, t_time = TIME):
 
     L_Motor.ChangeDutyCycle(speed)
     GPIO.output(AIN2,False)#AIN2
@@ -319,8 +319,7 @@ def loop():
     while True:
 
         while not RUNNING:
-            t_stop(0)
-            time.sleep(0.5)
+            t_stop(1) # after stopping acc, the vehicle will enter step mode.
 
         if True:
             near_verge = False # the current fall detection is too sensative, turn it off
@@ -365,7 +364,7 @@ def loop():
                 t_right(SPEED,0.3)
                 t_stop(0.1)
         else:
-            t_up(SPEED,0)           
+            t_up(SPEED,0)
         
         
         ################### The tracking band function #################
