@@ -9,7 +9,14 @@
 #
 #---------------------------------------------------
 
-import RPi.GPIO as GPIO
+import sys
+import os.path
+if sys.platform == 'win32' or not __package__:
+    sys.path.append(os.path.dirname(__file__))
+    from simulator import GPIO
+else:
+    import RPi.GPIO as GPIO
+
 import time
 
 Buzzer = 17
