@@ -34,6 +34,11 @@ class GPIO:
     def cleanup():
         pass
 
+    def add_event_detect(pin, mode,
+                callback,
+                bouncetime):
+        pass
+
 class PWM:
 
     def __init__(self, channel, freq):
@@ -49,7 +54,7 @@ class PWM:
         pass
 
     def ChangeFrequency(self, freq):
-        pass
+        pass    
 
 class SMBus:
     
